package com.hangum.vocabulary.dialog;

import java.io.File;
import java.io.FileOutputStream;
import java.util.HashMap;
import java.util.Iterator;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Dialog;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import com.hangum.vocabulary.data.DataFileHandler;

/**
 * vocabulary export 
 * 
 * @since 08.05.20
 * @author hangum(hangum@gmail.com)
 *
 */
public class ExportDialog extends Dialog {

	private Text textExport;
	protected Object result;
	DataFileHandler dfh;

	protected Shell shell;
	Label labelFileName;
	
	String fileName = File.separator + "export_vocabulary.txt";

	/**
	 * Create the dialog
	 * @param parent
	 * @param style
	 */
	public ExportDialog(Shell parent, int style) {
		super(parent, style);
	}

	/**
	 * Create the dialog
	 * @param parent
	 */
	public ExportDialog(Shell parent) {
		this(parent, SWT.NONE);
	}

	/**
	 * Open the dialog
	 * @return the result
	 */
	public Object open(DataFileHandler dfh) {
		this.dfh = dfh;
		
		createContents();
		shell.open();
		shell.layout();
		Display display = getParent().getDisplay();
		while (!shell.isDisposed()) {
			if (!display.readAndDispatch())
				display.sleep();
		}
		return result;
	}

	/**
	 * Create contents of the dialog
	 */
	protected void createContents() {
		shell = new Shell(getParent(), SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
		shell.setSize(522, 114);
		shell.setText("Export Dialog");

		final Label label = new Label(shell, SWT.NONE);
		label.setText("ġ");
		label.setBounds(10, 10, 42, 15);

		textExport = new Text(shell, SWT.BORDER);
		textExport.setEnabled(false);
		textExport.setBounds(59, 7, 263, 25);

		final Button searchButton = new Button(shell, SWT.NONE);
		searchButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(final SelectionEvent e) {
				searchDirectory();
			}
		});
		searchButton.setText("search");
		searchButton.setBounds(457, 5, 48, 25);

		final Button closeButton = new Button(shell, SWT.NONE);
		closeButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(final SelectionEvent e) {
				shell.close();
			}
		});
		closeButton.setText("close");
		closeButton.setBounds(457, 53, 48, 25);

		final Button exportButton = new Button(shell, SWT.NONE);
		exportButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(final SelectionEvent e) {
				export();
			}
		});
		exportButton.setText("export");
		exportButton.setBounds(403, 53, 48, 25);

		labelFileName = new Label(shell, SWT.NONE);
		labelFileName.setBounds(328, 10, 123, 22);
		//
		labelFileName.setText(fileName);
	}
	
	/**
	 * export  
	 *
	 */
	private void export() {
		try {
			String strExport = textExport.getText().trim();
	
			if("".equals(strExport)) {
				
				MessageDialog.openError(null, "", "Export Directory ּ.");
				return;
			} else {
				HashMap<Integer, String[]> mapKnow = dfh.getMapKnow();
//				HashMap<String, String[]> mapUnKnow = dfh.getMapUnKnow();
				HashMap<Integer, String[]> mapProgress = dfh.getMapProgress();

				StringBuffer sb = new StringBuffer();
				
//				System.out.println("亯  => " + mapKnow.size());
				Iterator iterator = mapKnow.keySet().iterator();
				while (iterator.hasNext()) {
					Integer key = (Integer) iterator.next();
					
					String[] arryStr = mapKnow.get(key);
					sb.append(arryStr[0]).append(DataFileHandler.MAIN_DELIMIT).append(arryStr[1]).append("\r\n");
					
//					System.out.println("[know]" + arryStr[0] + ":" + arryStr[1]);
				}
				
//				iterator = mapUnKnow.keySet().iterator();
//				while (iterator.hasNext()) {
//					String key = (String) iterator.next();
//					
//					String[] arryStr = mapUnKnow.get(key);
//					sb.append(arryStr[0]).append(DataFileHandler.MAIN_DELIMIT).append(arryStr[1]).append("\r\n");
//					
//					System.out.println("[unknow]" + arryStr[0] + ":" + arryStr[1]);
//				}			
				
//				System.out.println("  => " +mapProgress.size());
				
				iterator = mapProgress.keySet().iterator();
				while (iterator.hasNext()) {
					Integer key = (Integer) iterator.next();
					
					String[] arryStr = mapProgress.get(key);
//					System.out.println("key==> " + key);
					if(arryStr != null) {
//						System.out.println("[unknow]" + arryStr[0] + ":" + arryStr[1]);
						
						sb.append(arryStr[0]).append(DataFileHandler.MAIN_DELIMIT).append(arryStr[1]).append("\r\n");
					}
				}
				
				strExport += File.separator + labelFileName.getText();
				FileOutputStream fos = new FileOutputStream(strExport);
				fos.write(sb.toString().getBytes(), 0, sb.toString().length());
				fos.flush();
				fos.close();	
				
				
				MessageDialog.openError(null, "", "Export Ϸ߽ϴ.");
				shell.close();
			}
		} catch(Exception e) {
			e.printStackTrace();
			
			MessageDialog.openError(null, "", "Exportϴ ߿    ߻߽ϴ." + e.getMessage());
		}
	}
	
	/**
	 * export directory 
	 *
	 */
	private void searchDirectory() {
		DirectoryDialog directoryDialog = new DirectoryDialog(shell);
        
		String sysDrive = System.getenv("SystemDrive");
		if(sysDrive == null) sysDrive = System.getenv("HOMEDRIVE");
        
        directoryDialog.setFilterPath(sysDrive);
        directoryDialog.setMessage("Please select a directory and click OK");
        
        String dir = directoryDialog.open();
        if(dir != null) {
        	File f = new File(dir);
        	if(!f.canWrite()) {
        		MessageDialog.openError(null, "Ȯ", dir + "丮   ϴ.");
        	} else {
        		textExport.setText(dir);
        	}
        }
	}
}
